Thanks for contributing a PR!

Here's a quick checklist of what we'd like you to think off:

- [ ] Make sure to include one or more tests for your change;
- [ ] if an enhancement PR please create docs and at best an example
- [ ] Add yourself to `CONTRIBUTORS`;
- [ ] make a descriptive Pull Request text (it will be used for changelog)
